==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sv.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Användaröversikt",
    "Sent on: {on}" : "Sändes: {on}",
    "An error occurred while sending your report." : "Ett fel inträffade när rapporten sändes.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Applista <em>(för varje app: namn, version, aktiveringsstatus)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasmiljö <em>(typ, version, databasstorlek)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformation <em>(Aktiverad?, modul i grundinställningar)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delningar <em>(per typ och rättighetsinställning)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljö<em>(version, minnesgräns, max. exekveringstid, max. filstorlek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstansdetaljer <em>(version, använt memcache, status över låsning/förhandsvisning/avatarer)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, användare, lagringar per typ, kommentarer och taggar)</em>",
    "Help improve Nextcloud" : "Hjälp till att  förbättra Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vill du hjälpa oss förbättra Nextcloud genom att förse oss med anonym data om din installation och användning? Du kan stänga av det när som helst i administratörsinställningarna.",
    "Not now" : "Inte nu",
    "Send usage" : "Sänd användning",
    "Never" : "Aldrig",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa till att förbättra Nextcloud genom att sända oss viss data om din nuvarande installation och användning.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar din integritet på allvar. Skicka data är inaktiverat som standard och om du ändå vill sätta på det blir det först anonymiserat och du får välja vad som ska delas. När en rapport tas emot kommer den förra tas bort. Ladda upp en ren rapport för att ta bort all data som lagras på servern nu",
    "Send new report now" : "Skicka rapporten nu",
    "Send usage survey monthly" : "Skicka användaröversikt månadsvis",
    "Data to send" : "Data att sända",
    "Last report" : "Senaste rapport",
    "Sent on: %s" : "Sändes: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Applista <em>(för varje app: namn, version, aktiverad?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Serverinstansdetaljer <em>(version, använt minne, låst/förhandsvisning/avatarer aktiverat?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Du kan hjälpa oss förbättra Nextcloud genom att sända oss data från din nuvarande installation och användning.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vi tar din integritet på allvar. Datan är anonymiserad och du kan aktivera/inaktivera det när som helst, som standard är det alltid inaktiverat. Nedanför kan du också justera vilken typ av data som sänds och alltid se den senaste rapporten som sändes till oss. När servern tar emot en ny rapport av din instans, tas allt innehåll från tidigare rapporter bort. I fall du vill inaktivera någon av inställningarna nedan kan du sända en ny rapport för att ta bort datan som för tillfället är lagrat på servern.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa oss förbättra Nextcloud genom att sända oss data om din nuvarande installation och användning.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi tar din integritet på allvar. Datan är anonymiserad och du kan aktivera/inaktivera det när som helst, som standard är det alltid inaktiverat. Nedanför kan du också justera vilken typ av data som sänds och alltid se den senaste rapporten som sändes till oss. När servern tar emot en ny rapport av din instans, tas allt innehåll från tidigare rapporter bort. I fall du vill inaktivera någon av inställningarna nedan kan du sända en ny rapport som kommer att ta bort datan som för tillfället är lagrat på servern."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sv.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Skicka statistik",
    "Sent on: {on}" : "Sändes: {on}",
    "An error occurred while sending your report." : "Ett fel inträffade när rapporten sändes.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Applista <em>(för varje app: namn, version, aktiveringsstatus)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasmiljö <em>(typ, version, databasstorlek)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformation <em>(Aktiverad?, modul i grundinställningar)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delningar <em>(per typ och rättighetsinställning)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljö<em>(version, minnesgräns, max. exekveringstid, max. filstorlek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstansdetaljer <em>(version, använt memcache, status över låsning/förhandsvisning/avatarer)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, användare, lagringar per typ, kommentarer och taggar)</em>",
    "Help improve Nextcloud" : "Hjälp till att  förbättra Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vill du hjälpa oss förbättra Nextcloud genom att förse oss med anonym data om din installation och användning? Du kan stänga av det när som helst i administratörsinställningarna.",
    "Not now" : "Inte nu",
    "Send usage" : "Skicka statistik",
    "Never" : "Aldrig",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa till att förbättra Nextcloud genom att sända oss viss data om din nuvarande installation och användning.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar din integritet på allvar. Skicka data är inaktiverat som standard och om du ändå vill sätta på det blir det först anonymiserat och du får välja vad som ska delas. När en rapport tas emot kommer den förra tas bort. Ladda upp en ren rapport för att ta bort all data som lagras på servern nu",
    "Send new report now" : "Skicka rapporten nu",
    "Send usage survey monthly" : "Skicka användarstatistik månadsvis",
    "Data to send" : "Data att inkludera",
    "Last report" : "Senaste rapport",
    "Sent on: %s" : "Sändes: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Applista <em>(för varje app: namn, version, aktiverad?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Serverinstansdetaljer <em>(version, använt minne, låst/förhandsvisning/avatarer aktiverat?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Du kan hjälpa oss förbättra Nextcloud genom att sända oss data från din nuvarande installation och användning.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Vi tar din integritet på allvar. Datan är anonymiserad och du kan aktivera/inaktivera det när som helst, som standard är det alltid inaktiverat. Nedanför kan du också justera vilken typ av data som sänds och alltid se den senaste rapporten som sändes till oss. När servern tar emot en ny rapport av din instans, tas allt innehåll från tidigare rapporter bort. I fall du vill inaktivera någon av inställningarna nedan kan du sända en ny rapport för att ta bort datan som för tillfället är lagrat på servern.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa oss förbättra Nextcloud genom att sända oss data om din nuvarande installation och användning.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Vi tar din integritet på allvar. Datan är anonymiserad och du kan aktivera/inaktivera det när som helst, som standard är det alltid inaktiverat. Nedanför kan du också justera vilken typ av data som sänds och alltid se den senaste rapporten som sändes till oss. När servern tar emot en ny rapport av din instans, tas allt innehåll från tidigare rapporter bort. I fall du vill inaktivera någon av inställningarna nedan kan du sända en ny rapport som kommer att ta bort datan som för tillfället är lagrat på servern."
},
"nplurals=2; plural=(n != 1);");
